/*
 * Copyright (c) 2022.   Written by Aravind Chowdary
 */

library basepack_switch;

import 'dart:ui';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';

part '../aqua/animation_switch.dart';

part 'thumb_painter.dart';

class BasePackFancySwitch extends StatefulWidget {
  //create a switcher with animation similar https://dribbble.com/shots/5429846-Switcher-XLIV
  const BasePackFancySwitch({
    Key? key,
    required this.value,
    required this.onChanged,
    this.activeColor = Colors.blue,
    this.unActiveColor = Colors.grey,
    this.thumbColor = Colors.white,
  }) : super(key: key);

  final bool value;

  final ValueChanged<bool> onChanged;

  final Color activeColor;

  final Color unActiveColor;

  final Color thumbColor;

  @override
  _BasePackFancySwitchState createState() => _BasePackFancySwitchState();

  @override
  void debugFillProperties(DiagnosticPropertiesBuilder properties) {
    super.debugFillProperties(properties);
    properties.add(FlagProperty('value', value: value, ifTrue: 'on', ifFalse: 'off', showName: true));
    properties.add(ObjectFlagProperty<ValueChanged<bool>>('onChanged', onChanged, ifNull: 'disabled'));
  }
}

class _BasePackFancySwitchState extends State<BasePackFancySwitch> with TickerProviderStateMixin {
  Color unActiveColor = Colors.grey;

  @override
  void initState() {
    super.initState();
    unActiveColor = widget.unActiveColor;
  }

  @override
  Widget build(BuildContext context) {
    if (unActiveColor != widget.unActiveColor) {
      return _XlivSwitchRenderObjectWidget(
        value: widget.value,
        activeColor: widget.activeColor,
        onChanged: widget.onChanged,
        thumbColor: widget.thumbColor,
        unActiveColor: widget.unActiveColor,
        vsync: this,
        key: const Key('key'),
      );
    }
    return _XlivSwitchRenderObjectWidget(
      value: widget.value,
      activeColor: widget.activeColor,
      onChanged: widget.onChanged,
      thumbColor: widget.thumbColor,
      unActiveColor: unActiveColor,
      vsync: this,
    );
  }
}
