/*
 * Copyright (c) 2022.   Written by Aravind Chowdary
 */

import 'package:flutter/material.dart';

class BasePackSettingsItem extends StatefulWidget {
  const BasePackSettingsItem({
    Key? key,
    this.title = '',
    required this.onTap,
    this.subTitle = '',
    this.suffix = const SizedBox(),
  }) : super(key: key);

  final String title;
  final String subTitle;
  final void Function() onTap;
  final Widget suffix;

  @override
  State createState() => _BasePackSettingsItemState();
}

class _BasePackSettingsItemState extends State<BasePackSettingsItem> {
  @override
  Widget build(BuildContext context) {
    return InkWell(
      customBorder: const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(10))),
      splashColor: Colors.white54,
      splashFactory: InkRipple.splashFactory,
      onTap: widget.onTap,
      // splashColor: Colors.black12,
      // highlightColor: Colors.black12,
      child: Container(
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(10),
        ),
        padding: const EdgeInsets.symmetric(
          vertical: 3,
          horizontal: 8,
        ),
        child: ConstrainedBox(
          constraints: BoxConstraints(minHeight: 56),
          child: Align(
            alignment: Alignment.centerLeft,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Expanded(
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                    children: [
                      Text(
                        widget.title,
                        style: TextStyle(
                          color: Colors.black.withOpacity(0.86),
                          // color: Theme.of(context).colorScheme.primaryVariant,
                          fontWeight: FontWeight.bold,
                          fontFamily: 'Proxima',
                          fontSize: 15,
                          // height: 1.0,
                        ),
                      ),
                      const SizedBox(height: 2),
                      if (widget.subTitle.isNotEmpty)
                        Builder(builder: (_) {
                          final String content = widget.subTitle;
                          if (content == null) {
                            return const SizedBox();
                          }
                          return Text(
                            content,
                            style: TextStyle(
                              color: Colors.grey.withOpacity(0.6),
                              fontWeight: FontWeight.w500,
                              fontFamily: 'Proxima',
                              // height: 1.0,
                              fontSize: 12,
                            ),
                          );
                        }),
                    ],
                  ),
                ),
                widget.suffix,
              ],
            ),
          ),
        ),
      ),
    );
  }
}

class SettingHeader extends StatelessWidget {
  const SettingHeader({
    Key? key,
    required this.title,
    this.textColor = Colors.black45,
    this.fontSize = 12,
  }) : super(key: key);

  final String title;
  final Color textColor;
  final double fontSize;

  @override
  Widget build(BuildContext context) {
    return Container(
        padding: const EdgeInsets.symmetric(horizontal: 10),
        child: Text(title,
            style:
                TextStyle(color: textColor, fontSize: fontSize, fontFamily: 'Proxima', fontWeight: FontWeight.bold)));
  }
}
