import 'dart:convert';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter_markdown/flutter_markdown.dart';
import 'package:url_launcher/url_launcher.dart';

class BasePackMarkdownViewerScreen extends StatefulWidget {
  final String title;
  final int fetchType;
  final String path;
  final MarkdownStyleSheet? styleSheet;

  const BasePackMarkdownViewerScreen({
    Key? key,
    this.title = " ",
    this.fetchType = 1,
    this.styleSheet,
    required this.path,
  }) : super(key: key);

  @override
  State<BasePackMarkdownViewerScreen> createState() => _BasePackMarkdownViewerScreenState();
}

class _BasePackMarkdownViewerScreenState extends State<BasePackMarkdownViewerScreen> {
  @override
  Widget build(BuildContext context) {
    // future according to the type given
    var futureBuilt = widget.fetchType == 1 ? DefaultAssetBundle.of(context).loadString(widget.path) : net(widget.path);
    return Scaffold(
      appBar: AppBar(
        elevation: 1,
        scrolledUnderElevation: 1,
        title: Text(widget.title, style: const TextStyle(color: Colors.black, fontWeight: FontWeight.bold)),
      ),
      body: FutureBuilder(
        future: futureBuilt,
        builder: (context, snapshot) {
          if (snapshot.hasData) {
            return SingleChildScrollView(
              child: Container(
                padding: const EdgeInsets.all(10),
                child: MarkdownBody(
                  data: snapshot.data.toString(),
                  shrinkWrap: false,
                  onTapLink: (text, href, title) {
                    launchUrl(Uri.parse(href!),
                        // launch in external browser for android as it shows a crapy webview
                        mode: Platform.isAndroid ? LaunchMode.externalApplication : LaunchMode.inAppWebView);
                  },
                  // platform specific theme
                  styleSheetTheme:
                      Platform.isAndroid ? MarkdownStyleSheetBaseTheme.material : MarkdownStyleSheetBaseTheme.cupertino,
                  styleSheet: widget.styleSheet ??
                      MarkdownStyleSheet(
                        blockSpacing: 16,
                        p: const TextStyle(fontSize: 14, fontFamily: "Proxima"),
                        strong: const TextStyle(fontSize: 16, fontWeight: FontWeight.bold, fontFamily: "Google Sans"),
                        h2: const TextStyle(fontSize: 22, fontWeight: FontWeight.bold),
                        h3: const TextStyle(fontSize: 20, fontWeight: FontWeight.bold),
                        h4: const TextStyle(fontSize: 18, fontWeight: FontWeight.bold),
                        h5: const TextStyle(fontSize: 16, fontWeight: FontWeight.bold),
                        h6: const TextStyle(fontSize: 14, fontWeight: FontWeight.bold),
                      ),
                ),
              ),
            );
          } else {
            if (snapshot.hasError) {
              return Center(
                child: Text(snapshot.error.toString()),
              );
            } else {
              return const Center(
                  child: SizedBox(
                height: 32,
                width: 32,
                child: CircularProgressIndicator.adaptive(
                  valueColor: AlwaysStoppedAnimation<Color>(Colors.black),
                  strokeWidth: 2.76,
                ),
              ));
            }
          }
        },
      ),
    );
  }

  Future<String> net(String url) async {
    HttpClient client = HttpClient();
    var request = await client.getUrl(Uri.parse(url));
    var response = await request.close();
    var responseBody = await response.transform(utf8.decoder).join();
    // print(responseBody);
    return responseBody;
  }
}
